/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.builders;


public class Builders {
    
    public static ActionBuilder action() {
        return new ActionBuilder();
    }
    
    public static AffinityGroupBuilder affinityGroup() {
        return new AffinityGroupBuilder();
    }
    
    public static AffinityLabelBuilder affinityLabel() {
        return new AffinityLabelBuilder();
    }
    
    public static AffinityRuleBuilder affinityRule() {
        return new AffinityRuleBuilder();
    }
    
    public static AgentBuilder agent() {
        return new AgentBuilder();
    }
    
    public static AgentConfigurationBuilder agentConfiguration() {
        return new AgentConfigurationBuilder();
    }
    
    public static ApiBuilder api() {
        return new ApiBuilder();
    }
    
    public static ApiSummaryBuilder apiSummary() {
        return new ApiSummaryBuilder();
    }
    
    public static ApiSummaryItemBuilder apiSummaryItem() {
        return new ApiSummaryItemBuilder();
    }
    
    public static ApplicationBuilder application() {
        return new ApplicationBuilder();
    }
    
    public static AuthorizedKeyBuilder authorizedKey() {
        return new AuthorizedKeyBuilder();
    }
    
    public static BackupBuilder backup() {
        return new BackupBuilder();
    }
    
    public static BalanceBuilder balance() {
        return new BalanceBuilder();
    }
    
    public static BiosBuilder bios() {
        return new BiosBuilder();
    }
    
    public static BlockStatisticBuilder blockStatistic() {
        return new BlockStatisticBuilder();
    }
    
    public static BondingBuilder bonding() {
        return new BondingBuilder();
    }
    
    public static BookmarkBuilder bookmark() {
        return new BookmarkBuilder();
    }
    
    public static BootBuilder boot() {
        return new BootBuilder();
    }
    
    public static BootMenuBuilder bootMenu() {
        return new BootMenuBuilder();
    }
    
    public static BrickProfileDetailBuilder brickProfileDetail() {
        return new BrickProfileDetailBuilder();
    }
    
    public static CdromBuilder cdrom() {
        return new CdromBuilder();
    }
    
    public static CertificateBuilder certificate() {
        return new CertificateBuilder();
    }
    
    public static CloudInitBuilder cloudInit() {
        return new CloudInitBuilder();
    }
    
    public static ClusterBuilder cluster() {
        return new ClusterBuilder();
    }
    
    public static ClusterFeatureBuilder clusterFeature() {
        return new ClusterFeatureBuilder();
    }
    
    public static ClusterLevelBuilder clusterLevel() {
        return new ClusterLevelBuilder();
    }
    
    public static ConfigurationBuilder configuration() {
        return new ConfigurationBuilder();
    }
    
    public static ConsoleBuilder console() {
        return new ConsoleBuilder();
    }
    
    public static CoreBuilder core() {
        return new CoreBuilder();
    }
    
    public static CpuBuilder cpu() {
        return new CpuBuilder();
    }
    
    public static CpuProfileBuilder cpuProfile() {
        return new CpuProfileBuilder();
    }
    
    public static CpuTopologyBuilder cpuTopology() {
        return new CpuTopologyBuilder();
    }
    
    public static CpuTuneBuilder cpuTune() {
        return new CpuTuneBuilder();
    }
    
    public static CpuTypeBuilder cpuType() {
        return new CpuTypeBuilder();
    }
    
    public static CustomPropertyBuilder customProperty() {
        return new CustomPropertyBuilder();
    }
    
    public static DataCenterBuilder dataCenter() {
        return new DataCenterBuilder();
    }
    
    public static DeviceBuilder device() {
        return new DeviceBuilder();
    }
    
    public static DiskBuilder disk() {
        return new DiskBuilder();
    }
    
    public static DiskAttachmentBuilder diskAttachment() {
        return new DiskAttachmentBuilder();
    }
    
    public static DiskProfileBuilder diskProfile() {
        return new DiskProfileBuilder();
    }
    
    public static DiskSnapshotBuilder diskSnapshot() {
        return new DiskSnapshotBuilder();
    }
    
    public static DisplayBuilder display() {
        return new DisplayBuilder();
    }
    
    public static DnsBuilder dns() {
        return new DnsBuilder();
    }
    
    public static DnsResolverConfigurationBuilder dnsResolverConfiguration() {
        return new DnsResolverConfigurationBuilder();
    }
    
    public static DomainBuilder domain() {
        return new DomainBuilder();
    }
    
    public static EntityProfileDetailBuilder entityProfileDetail() {
        return new EntityProfileDetailBuilder();
    }
    
    public static ErrorHandlingBuilder errorHandling() {
        return new ErrorHandlingBuilder();
    }
    
    public static EventBuilder event() {
        return new EventBuilder();
    }
    
    public static ExternalComputeResourceBuilder externalComputeResource() {
        return new ExternalComputeResourceBuilder();
    }
    
    public static ExternalDiscoveredHostBuilder externalDiscoveredHost() {
        return new ExternalDiscoveredHostBuilder();
    }
    
    public static ExternalHostBuilder externalHost() {
        return new ExternalHostBuilder();
    }
    
    public static ExternalHostGroupBuilder externalHostGroup() {
        return new ExternalHostGroupBuilder();
    }
    
    public static ExternalHostProviderBuilder externalHostProvider() {
        return new ExternalHostProviderBuilder();
    }
    
    public static ExternalNetworkProviderConfigurationBuilder externalNetworkProviderConfiguration() {
        return new ExternalNetworkProviderConfigurationBuilder();
    }
    
    public static ExternalProviderBuilder externalProvider() {
        return new ExternalProviderBuilder();
    }
    
    public static ExternalVmImportBuilder externalVmImport() {
        return new ExternalVmImportBuilder();
    }
    
    public static FaultBuilder fault() {
        return new FaultBuilder();
    }
    
    public static FencingPolicyBuilder fencingPolicy() {
        return new FencingPolicyBuilder();
    }
    
    public static FileBuilder file() {
        return new FileBuilder();
    }
    
    public static FilterBuilder filter() {
        return new FilterBuilder();
    }
    
    public static FloppyBuilder floppy() {
        return new FloppyBuilder();
    }
    
    public static FopStatisticBuilder fopStatistic() {
        return new FopStatisticBuilder();
    }
    
    public static GlusterBrickBuilder glusterBrick() {
        return new GlusterBrickBuilder();
    }
    
    public static GlusterBrickAdvancedDetailsBuilder glusterBrickAdvancedDetails() {
        return new GlusterBrickAdvancedDetailsBuilder();
    }
    
    public static GlusterBrickMemoryInfoBuilder glusterBrickMemoryInfo() {
        return new GlusterBrickMemoryInfoBuilder();
    }
    
    public static GlusterClientBuilder glusterClient() {
        return new GlusterClientBuilder();
    }
    
    public static GlusterHookBuilder glusterHook() {
        return new GlusterHookBuilder();
    }
    
    public static GlusterMemoryPoolBuilder glusterMemoryPool() {
        return new GlusterMemoryPoolBuilder();
    }
    
    public static GlusterServerHookBuilder glusterServerHook() {
        return new GlusterServerHookBuilder();
    }
    
    public static GlusterVolumeBuilder glusterVolume() {
        return new GlusterVolumeBuilder();
    }
    
    public static GlusterVolumeProfileDetailsBuilder glusterVolumeProfileDetails() {
        return new GlusterVolumeProfileDetailsBuilder();
    }
    
    public static GracePeriodBuilder gracePeriod() {
        return new GracePeriodBuilder();
    }
    
    public static GraphicsConsoleBuilder graphicsConsole() {
        return new GraphicsConsoleBuilder();
    }
    
    public static GroupBuilder group() {
        return new GroupBuilder();
    }
    
    public static GuestOperatingSystemBuilder guestOperatingSystem() {
        return new GuestOperatingSystemBuilder();
    }
    
    public static HardwareInformationBuilder hardwareInformation() {
        return new HardwareInformationBuilder();
    }
    
    public static HighAvailabilityBuilder highAvailability() {
        return new HighAvailabilityBuilder();
    }
    
    public static HookBuilder hook() {
        return new HookBuilder();
    }
    
    public static HostBuilder host() {
        return new HostBuilder();
    }
    
    public static HostDeviceBuilder hostDevice() {
        return new HostDeviceBuilder();
    }
    
    public static HostDevicePassthroughBuilder hostDevicePassthrough() {
        return new HostDevicePassthroughBuilder();
    }
    
    public static HostNicBuilder hostNic() {
        return new HostNicBuilder();
    }
    
    public static HostNicVirtualFunctionsConfigurationBuilder hostNicVirtualFunctionsConfiguration() {
        return new HostNicVirtualFunctionsConfigurationBuilder();
    }
    
    public static HostStorageBuilder hostStorage() {
        return new HostStorageBuilder();
    }
    
    public static HostedEngineBuilder hostedEngine() {
        return new HostedEngineBuilder();
    }
    
    public static IconBuilder icon() {
        return new IconBuilder();
    }
    
    public static IdentifiedBuilder identified() {
        return new IdentifiedBuilder();
    }
    
    public static ImageBuilder image() {
        return new ImageBuilder();
    }
    
    public static ImageTransferBuilder imageTransfer() {
        return new ImageTransferBuilder();
    }
    
    public static InitializationBuilder initialization() {
        return new InitializationBuilder();
    }
    
    public static InstanceTypeBuilder instanceType() {
        return new InstanceTypeBuilder();
    }
    
    public static IoBuilder io() {
        return new IoBuilder();
    }
    
    public static IpBuilder ip() {
        return new IpBuilder();
    }
    
    public static IpAddressAssignmentBuilder ipAddressAssignment() {
        return new IpAddressAssignmentBuilder();
    }
    
    public static IscsiBondBuilder iscsiBond() {
        return new IscsiBondBuilder();
    }
    
    public static IscsiDetailsBuilder iscsiDetails() {
        return new IscsiDetailsBuilder();
    }
    
    public static JobBuilder job() {
        return new JobBuilder();
    }
    
    public static KatelloErratumBuilder katelloErratum() {
        return new KatelloErratumBuilder();
    }
    
    public static KernelBuilder kernel() {
        return new KernelBuilder();
    }
    
    public static KsmBuilder ksm() {
        return new KsmBuilder();
    }
    
    public static LinkLayerDiscoveryProtocolElementBuilder linkLayerDiscoveryProtocolElement() {
        return new LinkLayerDiscoveryProtocolElementBuilder();
    }
    
    public static LogicalUnitBuilder logicalUnit() {
        return new LogicalUnitBuilder();
    }
    
    public static MacBuilder mac() {
        return new MacBuilder();
    }
    
    public static MacPoolBuilder macPool() {
        return new MacPoolBuilder();
    }
    
    public static MemoryOverCommitBuilder memoryOverCommit() {
        return new MemoryOverCommitBuilder();
    }
    
    public static MemoryPolicyBuilder memoryPolicy() {
        return new MemoryPolicyBuilder();
    }
    
    public static MethodBuilder method() {
        return new MethodBuilder();
    }
    
    public static MigrationBandwidthBuilder migrationBandwidth() {
        return new MigrationBandwidthBuilder();
    }
    
    public static MigrationOptionsBuilder migrationOptions() {
        return new MigrationOptionsBuilder();
    }
    
    public static MigrationPolicyBuilder migrationPolicy() {
        return new MigrationPolicyBuilder();
    }
    
    public static NetworkBuilder network() {
        return new NetworkBuilder();
    }
    
    public static NetworkAttachmentBuilder networkAttachment() {
        return new NetworkAttachmentBuilder();
    }
    
    public static NetworkConfigurationBuilder networkConfiguration() {
        return new NetworkConfigurationBuilder();
    }
    
    public static NetworkFilterBuilder networkFilter() {
        return new NetworkFilterBuilder();
    }
    
    public static NetworkFilterParameterBuilder networkFilterParameter() {
        return new NetworkFilterParameterBuilder();
    }
    
    public static NetworkLabelBuilder networkLabel() {
        return new NetworkLabelBuilder();
    }
    
    public static NfsProfileDetailBuilder nfsProfileDetail() {
        return new NfsProfileDetailBuilder();
    }
    
    public static NicBuilder nic() {
        return new NicBuilder();
    }
    
    public static NicConfigurationBuilder nicConfiguration() {
        return new NicConfigurationBuilder();
    }
    
    public static NumaNodeBuilder numaNode() {
        return new NumaNodeBuilder();
    }
    
    public static NumaNodePinBuilder numaNodePin() {
        return new NumaNodePinBuilder();
    }
    
    public static OpenStackImageBuilder openStackImage() {
        return new OpenStackImageBuilder();
    }
    
    public static OpenStackImageProviderBuilder openStackImageProvider() {
        return new OpenStackImageProviderBuilder();
    }
    
    public static OpenStackNetworkBuilder openStackNetwork() {
        return new OpenStackNetworkBuilder();
    }
    
    public static OpenStackNetworkProviderBuilder openStackNetworkProvider() {
        return new OpenStackNetworkProviderBuilder();
    }
    
    public static OpenStackProviderBuilder openStackProvider() {
        return new OpenStackProviderBuilder();
    }
    
    public static OpenStackSubnetBuilder openStackSubnet() {
        return new OpenStackSubnetBuilder();
    }
    
    public static OpenStackVolumeProviderBuilder openStackVolumeProvider() {
        return new OpenStackVolumeProviderBuilder();
    }
    
    public static OpenStackVolumeTypeBuilder openStackVolumeType() {
        return new OpenStackVolumeTypeBuilder();
    }
    
    public static OpenstackVolumeAuthenticationKeyBuilder openstackVolumeAuthenticationKey() {
        return new OpenstackVolumeAuthenticationKeyBuilder();
    }
    
    public static OperatingSystemBuilder operatingSystem() {
        return new OperatingSystemBuilder();
    }
    
    public static OperatingSystemInfoBuilder operatingSystemInfo() {
        return new OperatingSystemInfoBuilder();
    }
    
    public static OptionBuilder option() {
        return new OptionBuilder();
    }
    
    public static PackageBuilder package_() {
        return new PackageBuilder();
    }
    
    public static PayloadBuilder payload() {
        return new PayloadBuilder();
    }
    
    public static PermissionBuilder permission() {
        return new PermissionBuilder();
    }
    
    public static PermitBuilder permit() {
        return new PermitBuilder();
    }
    
    public static PmProxyBuilder pmProxy() {
        return new PmProxyBuilder();
    }
    
    public static PortMirroringBuilder portMirroring() {
        return new PortMirroringBuilder();
    }
    
    public static PowerManagementBuilder powerManagement() {
        return new PowerManagementBuilder();
    }
    
    public static ProductBuilder product() {
        return new ProductBuilder();
    }
    
    public static ProductInfoBuilder productInfo() {
        return new ProductInfoBuilder();
    }
    
    public static ProfileDetailBuilder profileDetail() {
        return new ProfileDetailBuilder();
    }
    
    public static PropertyBuilder property() {
        return new PropertyBuilder();
    }
    
    public static ProxyTicketBuilder proxyTicket() {
        return new ProxyTicketBuilder();
    }
    
    public static QosBuilder qos() {
        return new QosBuilder();
    }
    
    public static QuotaBuilder quota() {
        return new QuotaBuilder();
    }
    
    public static QuotaClusterLimitBuilder quotaClusterLimit() {
        return new QuotaClusterLimitBuilder();
    }
    
    public static QuotaStorageLimitBuilder quotaStorageLimit() {
        return new QuotaStorageLimitBuilder();
    }
    
    public static RangeBuilder range() {
        return new RangeBuilder();
    }
    
    public static RateBuilder rate() {
        return new RateBuilder();
    }
    
    public static RegistrationAffinityGroupMappingBuilder registrationAffinityGroupMapping() {
        return new RegistrationAffinityGroupMappingBuilder();
    }
    
    public static RegistrationAffinityLabelMappingBuilder registrationAffinityLabelMapping() {
        return new RegistrationAffinityLabelMappingBuilder();
    }
    
    public static RegistrationClusterMappingBuilder registrationClusterMapping() {
        return new RegistrationClusterMappingBuilder();
    }
    
    public static RegistrationConfigurationBuilder registrationConfiguration() {
        return new RegistrationConfigurationBuilder();
    }
    
    public static RegistrationDomainMappingBuilder registrationDomainMapping() {
        return new RegistrationDomainMappingBuilder();
    }
    
    public static RegistrationLunMappingBuilder registrationLunMapping() {
        return new RegistrationLunMappingBuilder();
    }
    
    public static RegistrationRoleMappingBuilder registrationRoleMapping() {
        return new RegistrationRoleMappingBuilder();
    }
    
    public static RegistrationVnicProfileMappingBuilder registrationVnicProfileMapping() {
        return new RegistrationVnicProfileMappingBuilder();
    }
    
    public static ReportedConfigurationBuilder reportedConfiguration() {
        return new ReportedConfigurationBuilder();
    }
    
    public static ReportedDeviceBuilder reportedDevice() {
        return new ReportedDeviceBuilder();
    }
    
    public static RngDeviceBuilder rngDevice() {
        return new RngDeviceBuilder();
    }
    
    public static RoleBuilder role() {
        return new RoleBuilder();
    }
    
    public static SchedulingPolicyBuilder schedulingPolicy() {
        return new SchedulingPolicyBuilder();
    }
    
    public static SchedulingPolicyUnitBuilder schedulingPolicyUnit() {
        return new SchedulingPolicyUnitBuilder();
    }
    
    public static SeLinuxBuilder seLinux() {
        return new SeLinuxBuilder();
    }
    
    public static SerialNumberBuilder serialNumber() {
        return new SerialNumberBuilder();
    }
    
    public static SessionBuilder session() {
        return new SessionBuilder();
    }
    
    public static SkipIfConnectivityBrokenBuilder skipIfConnectivityBroken() {
        return new SkipIfConnectivityBrokenBuilder();
    }
    
    public static SkipIfSdActiveBuilder skipIfSdActive() {
        return new SkipIfSdActiveBuilder();
    }
    
    public static SnapshotBuilder snapshot() {
        return new SnapshotBuilder();
    }
    
    public static SpecialObjectsBuilder specialObjects() {
        return new SpecialObjectsBuilder();
    }
    
    public static SpmBuilder spm() {
        return new SpmBuilder();
    }
    
    public static SshBuilder ssh() {
        return new SshBuilder();
    }
    
    public static SshPublicKeyBuilder sshPublicKey() {
        return new SshPublicKeyBuilder();
    }
    
    public static SsoBuilder sso() {
        return new SsoBuilder();
    }
    
    public static StatisticBuilder statistic() {
        return new StatisticBuilder();
    }
    
    public static StepBuilder step() {
        return new StepBuilder();
    }
    
    public static StorageConnectionBuilder storageConnection() {
        return new StorageConnectionBuilder();
    }
    
    public static StorageConnectionExtensionBuilder storageConnectionExtension() {
        return new StorageConnectionExtensionBuilder();
    }
    
    public static StorageDomainBuilder storageDomain() {
        return new StorageDomainBuilder();
    }
    
    public static StorageDomainLeaseBuilder storageDomainLease() {
        return new StorageDomainLeaseBuilder();
    }
    
    public static SystemOptionBuilder systemOption() {
        return new SystemOptionBuilder();
    }
    
    public static SystemOptionValueBuilder systemOptionValue() {
        return new SystemOptionValueBuilder();
    }
    
    public static TagBuilder tag() {
        return new TagBuilder();
    }
    
    public static TemplateBuilder template() {
        return new TemplateBuilder();
    }
    
    public static TemplateVersionBuilder templateVersion() {
        return new TemplateVersionBuilder();
    }
    
    public static TicketBuilder ticket() {
        return new TicketBuilder();
    }
    
    public static TimeZoneBuilder timeZone() {
        return new TimeZoneBuilder();
    }
    
    public static TransparentHugePagesBuilder transparentHugePages() {
        return new TransparentHugePagesBuilder();
    }
    
    public static UnmanagedNetworkBuilder unmanagedNetwork() {
        return new UnmanagedNetworkBuilder();
    }
    
    public static UsbBuilder usb() {
        return new UsbBuilder();
    }
    
    public static UserBuilder user() {
        return new UserBuilder();
    }
    
    public static ValueBuilder value() {
        return new ValueBuilder();
    }
    
    public static VcpuPinBuilder vcpuPin() {
        return new VcpuPinBuilder();
    }
    
    public static VendorBuilder vendor() {
        return new VendorBuilder();
    }
    
    public static VersionBuilder version() {
        return new VersionBuilder();
    }
    
    public static VirtioScsiBuilder virtioScsi() {
        return new VirtioScsiBuilder();
    }
    
    public static VirtualNumaNodeBuilder virtualNumaNode() {
        return new VirtualNumaNodeBuilder();
    }
    
    public static VlanBuilder vlan() {
        return new VlanBuilder();
    }
    
    public static VmBuilder vm() {
        return new VmBuilder();
    }
    
    public static VmBaseBuilder vmBase() {
        return new VmBaseBuilder();
    }
    
    public static VmPlacementPolicyBuilder vmPlacementPolicy() {
        return new VmPlacementPolicyBuilder();
    }
    
    public static VmPoolBuilder vmPool() {
        return new VmPoolBuilder();
    }
    
    public static VmSummaryBuilder vmSummary() {
        return new VmSummaryBuilder();
    }
    
    public static VnicPassThroughBuilder vnicPassThrough() {
        return new VnicPassThroughBuilder();
    }
    
    public static VnicProfileBuilder vnicProfile() {
        return new VnicProfileBuilder();
    }
    
    public static VnicProfileMappingBuilder vnicProfileMapping() {
        return new VnicProfileMappingBuilder();
    }
    
    public static VolumeGroupBuilder volumeGroup() {
        return new VolumeGroupBuilder();
    }
    
    public static WatchdogBuilder watchdog() {
        return new WatchdogBuilder();
    }
    
    public static WeightBuilder weight() {
        return new WeightBuilder();
    }
    
}
